@@ -12,7 +12,7 @@ from making_with_code_cli.styles import (
     address,
     question,
     info,
-    debug,
+    debug as debug_fmt,
     confirm,
     error,
 )
@@ -73,7 +73,8 @@ def setup(ctx, yes, teacher, config, debug):
     """Set up the MWC command line interface"""
     settings = read_settings(config)
     if debug:
-        click.echo(debug(f"Reading settings from {get_settings_path(config)}"))
+        sp = get_settings_path(config)
+        click.echo(debug_fmt(f"Reading settings from {sp}"))
     rc_tasks = []
     click.echo(address(INTRO_MESSAGE))
     for note in INTRO_NOTES:
@@ -130,7 +131,7 @@ def setup(ctx, yes, teacher, config, debug):
         for task, tb in errors:
             click.echo(error(task.description))
             if debug:
-                click.echo(debug(tb, preformatted=True))
+                click.echo(debug_fmt(tb, preformatted=True))
     ctx.invoke(update)
 
 def get_course_by_name(name, courses):
@@ -173,7 +174,7 @@ def update(config):
                 if 'init_action' in module:
                     rel_dir = module_dir.resolve().relative_to(mwc_home)
                     click.echo(confirm(f"Initializing {module['slug']} at {rel_dir}."))
-                    click.echo(confirm("See {module['url']} for details."))
+                    click.echo(confirm(f"See {module['url']} for details."))
                     try:
                         G.init_module(module, module_dir)
                     except Exception as e:
